# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import requests_pb2 as requests__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rgateway.proto\x12\x17hyrex.performanceserver\x1a\x0erequests.proto2\x86\x0e\n\x0eGatewayService\x12\\\n\x07\x45nqueue\x12\'.hyrex.performanceserver.EnqueueRequest\x1a(.hyrex.performanceserver.EnqueueResponse\x12\\\n\x07\x44\x65queue\x12\'.hyrex.performanceserver.DequeueRequest\x1a(.hyrex.performanceserver.DequeueResponse\x12\x62\n\tGetQueues\x12).hyrex.performanceserver.GetQueuesRequest\x1a*.hyrex.performanceserver.GetQueuesResponse\x12w\n\x10GetTaskRunStatus\x12\x30.hyrex.performanceserver.GetTaskRunStatusRequest\x1a\x31.hyrex.performanceserver.GetTaskRunStatusResponse\x12h\n\x0bMarkSuccess\x12+.hyrex.performanceserver.MarkSuccessRequest\x1a,.hyrex.performanceserver.MarkSuccessResponse\x12\x65\n\nMarkFailed\x12*.hyrex.performanceserver.MarkFailedRequest\x1a+.hyrex.performanceserver.MarkFailedResponse\x12\x65\n\nGetTaskRun\x12*.hyrex.performanceserver.GetTaskRunRequest\x1a+.hyrex.performanceserver.GetTaskRunResponse\x12}\n\x12GetDurableTaskRuns\x12\x32.hyrex.performanceserver.GetDurableTaskRunsRequest\x1a\x33.hyrex.performanceserver.GetDurableTaskRunsResponse\x12t\n\x0fRegisterTaskDef\x12/.hyrex.performanceserver.RegisterTaskDefRequest\x1a\x30.hyrex.performanceserver.RegisterTaskDefResponse\x12\x65\n\nGetTaskDef\x12*.hyrex.performanceserver.GetTaskDefRequest\x1a+.hyrex.performanceserver.GetTaskDefResponse\x12q\n\x0eGetAllTaskDefs\x12..hyrex.performanceserver.GetAllTaskDefsRequest\x1a/.hyrex.performanceserver.GetAllTaskDefsResponse\x12w\n\x10RegisterExecutor\x12\x30.hyrex.performanceserver.RegisterExecutorRequest\x1a\x31.hyrex.performanceserver.RegisterExecutorResponse\x12\x83\x01\n\x14UpdateExecutorQueues\x12\x34.hyrex.performanceserver.UpdateExecutorQueuesRequest\x1a\x35.hyrex.performanceserver.UpdateExecutorQueuesResponse\x12h\n\x0bRegisterApp\x12+.hyrex.performanceserver.RegisterAppRequest\x1a,.hyrex.performanceserver.RegisterAppResponse\x12\x65\n\nSetLogLink\x12*.hyrex.performanceserver.SetLogLinkRequest\x1a+.hyrex.performanceserver.SetLogLinkResponse\x12\x83\x01\n\x14\x41\x63quireSchedulerLock\x12\x34.hyrex.performanceserver.AcquireSchedulerLockRequest\x1a\x35.hyrex.performanceserver.AcquireSchedulerLockResponseB\x08Z\x06proto/b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\006proto/'
  _globals['_GATEWAYSERVICE']._serialized_start=59
  _globals['_GATEWAYSERVICE']._serialized_end=1857
# @@protoc_insertion_point(module_scope)
