# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: requests.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'requests.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from . import task_pb2 as task__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0erequests.proto\x12\x17hyrex.performanceserver\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\ntask.proto\"\x99\x04\n\x0e\x45nqueueRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\ndurable_id\x18\x02 \x01(\t\x12\x0f\n\x07root_id\x18\x03 \x01(\t\x12\x1c\n\x0fworkflow_run_id\x18\x04 \x01(\tH\x00\x88\x01\x01\x12\x1d\n\x15workflow_dependencies\x18\x05 \x03(\t\x12\x16\n\tparent_id\x18\x06 \x01(\tH\x01\x88\x01\x01\x12\x33\n\x06status\x18\x07 \x01(\x0e\x32#.hyrex.performanceserver.TaskStatus\x12\x11\n\ttask_name\x18\x08 \x01(\t\x12\x0c\n\x04\x61rgs\x18\t \x01(\x0c\x12\r\n\x05queue\x18\n \x01(\t\x12\x13\n\x0bmax_retries\x18\x0b \x01(\x05\x12\x33\n\x08priority\x18\x0c \x01(\x0e\x32!.hyrex.performanceserver.Priority\x12\x1c\n\x0ftimeout_seconds\x18\r \x01(\x05H\x02\x88\x01\x01\x12\x1c\n\x0fidempotency_key\x18\x0e \x01(\tH\x03\x88\x01\x01\x12\x38\n\x0fscheduled_start\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x04\x88\x01\x01\x42\x12\n\x10_workflow_run_idB\x0c\n\n_parent_idB\x12\n\x10_timeout_secondsB\x12\n\x10_idempotency_keyB\x12\n\x10_scheduled_start\"\x11\n\x0f\x45nqueueResponse\"4\n\x0e\x44\x65queueRequest\x12\x13\n\x0b\x65xecutor_id\x18\x01 \x01(\t\x12\r\n\x05queue\x18\x02 \x01(\t\"E\n\x0f\x44\x65queueResponse\x12\x32\n\x08task_run\x18\x01 \x01(\x0b\x32 .hyrex.performanceserver.TaskRun\";\n\x10GetQueuesRequest\x12\x16\n\x0emax_num_queues\x18\x01 \x01(\x05\x12\x0f\n\x07pattern\x18\x02 \x01(\t\"4\n\x11GetQueuesResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0e\n\x06queues\x18\x02 \x03(\t\"$\n\x11GetTaskRunRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\t\"H\n\x12GetTaskRunResponse\x12\x32\n\x08task_run\x18\x01 \x01(\x0b\x32 .hyrex.performanceserver.TaskRun\"*\n\x17GetTaskRunStatusRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\t\"O\n\x18GetTaskRunStatusResponse\x12\x33\n\x06status\x18\x01 \x01(\x0e\x32#.hyrex.performanceserver.TaskStatus\"E\n\x12MarkSuccessRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\x13\n\x06result\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\t\n\x07_result\"\x15\n\x13MarkSuccessResponse\"$\n\x11MarkFailedRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\t\"\x14\n\x12MarkFailedResponse\"/\n\x19GetDurableTaskRunsRequest\x12\x12\n\ndurable_id\x18\x01 \x01(\t\"Q\n\x1aGetDurableTaskRunsResponse\x12\x33\n\ttask_runs\x18\x02 \x03(\x0b\x32 .hyrex.performanceserver.TaskRun\"6\n\x11SetLogLinkRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\x10\n\x08log_link\x18\x02 \x01(\t\"\x14\n\x12SetLogLinkResponse\"L\n\x16RegisterTaskDefRequest\x12\x32\n\x08task_def\x18\x01 \x01(\x0b\x32 .hyrex.performanceserver.TaskDef\"\x19\n\x17RegisterTaskDefResponse\"&\n\x11GetTaskDefRequest\x12\x11\n\ttask_name\x18\x01 \x01(\t\"H\n\x12GetTaskDefResponse\x12\x32\n\x08task_def\x18\x01 \x01(\x0b\x32 .hyrex.performanceserver.TaskDef\"\x17\n\x15GetAllTaskDefsRequest\"M\n\x16GetAllTaskDefsResponse\x12\x33\n\ttask_defs\x18\x01 \x03(\x0b\x32 .hyrex.performanceserver.TaskDef\"\x15\n\x13RegisterCronRequest\"\x16\n\x14RegisterCronResponse\"\x81\x01\n\x17RegisterExecutorRequest\x12\x13\n\x0b\x65xecutor_id\x18\x01 \x01(\t\x12\x15\n\rexecutor_name\x18\x02 \x01(\t\x12\x15\n\rqueue_pattern\x18\x03 \x01(\t\x12\x0e\n\x06queues\x18\x04 \x03(\t\x12\x13\n\x0bworker_name\x18\x05 \x01(\t\"\x1a\n\x18RegisterExecutorResponse\"B\n\x1bUpdateExecutorQueuesRequest\x12\x13\n\x0b\x65xecutor_id\x18\x01 \x01(\t\x12\x0e\n\x06queues\x18\x02 \x03(\t\"\x1e\n\x1cUpdateExecutorQueuesResponse\"?\n\x12RegisterAppRequest\x12)\n\x08\x61pp_info\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\"\x15\n\x13RegisterAppResponse\"D\n\x1b\x41\x63quireSchedulerLockRequest\x12\x13\n\x0bworker_name\x18\x01 \x01(\t\x12\x10\n\x08\x64uration\x18\x02 \x01(\t\"@\n\x1c\x41\x63quireSchedulerLockResponse\x12\x14\n\x07lock_id\x18\x01 \x01(\x05H\x00\x88\x01\x01\x42\n\n\x08_lock_id\"\x17\n\x15TestConnectionRequest\"\x18\n\x16TestConnectionResponseB\x08Z\x06proto/b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'requests_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\006proto/'
  _globals['_ENQUEUEREQUEST']._serialized_start=119
  _globals['_ENQUEUEREQUEST']._serialized_end=656
  _globals['_ENQUEUERESPONSE']._serialized_start=658
  _globals['_ENQUEUERESPONSE']._serialized_end=675
  _globals['_DEQUEUEREQUEST']._serialized_start=677
  _globals['_DEQUEUEREQUEST']._serialized_end=729
  _globals['_DEQUEUERESPONSE']._serialized_start=731
  _globals['_DEQUEUERESPONSE']._serialized_end=800
  _globals['_GETQUEUESREQUEST']._serialized_start=802
  _globals['_GETQUEUESREQUEST']._serialized_end=861
  _globals['_GETQUEUESRESPONSE']._serialized_start=863
  _globals['_GETQUEUESRESPONSE']._serialized_end=915
  _globals['_GETTASKRUNREQUEST']._serialized_start=917
  _globals['_GETTASKRUNREQUEST']._serialized_end=953
  _globals['_GETTASKRUNRESPONSE']._serialized_start=955
  _globals['_GETTASKRUNRESPONSE']._serialized_end=1027
  _globals['_GETTASKRUNSTATUSREQUEST']._serialized_start=1029
  _globals['_GETTASKRUNSTATUSREQUEST']._serialized_end=1071
  _globals['_GETTASKRUNSTATUSRESPONSE']._serialized_start=1073
  _globals['_GETTASKRUNSTATUSRESPONSE']._serialized_end=1152
  _globals['_MARKSUCCESSREQUEST']._serialized_start=1154
  _globals['_MARKSUCCESSREQUEST']._serialized_end=1223
  _globals['_MARKSUCCESSRESPONSE']._serialized_start=1225
  _globals['_MARKSUCCESSRESPONSE']._serialized_end=1246
  _globals['_MARKFAILEDREQUEST']._serialized_start=1248
  _globals['_MARKFAILEDREQUEST']._serialized_end=1284
  _globals['_MARKFAILEDRESPONSE']._serialized_start=1286
  _globals['_MARKFAILEDRESPONSE']._serialized_end=1306
  _globals['_GETDURABLETASKRUNSREQUEST']._serialized_start=1308
  _globals['_GETDURABLETASKRUNSREQUEST']._serialized_end=1355
  _globals['_GETDURABLETASKRUNSRESPONSE']._serialized_start=1357
  _globals['_GETDURABLETASKRUNSRESPONSE']._serialized_end=1438
  _globals['_SETLOGLINKREQUEST']._serialized_start=1440
  _globals['_SETLOGLINKREQUEST']._serialized_end=1494
  _globals['_SETLOGLINKRESPONSE']._serialized_start=1496
  _globals['_SETLOGLINKRESPONSE']._serialized_end=1516
  _globals['_REGISTERTASKDEFREQUEST']._serialized_start=1518
  _globals['_REGISTERTASKDEFREQUEST']._serialized_end=1594
  _globals['_REGISTERTASKDEFRESPONSE']._serialized_start=1596
  _globals['_REGISTERTASKDEFRESPONSE']._serialized_end=1621
  _globals['_GETTASKDEFREQUEST']._serialized_start=1623
  _globals['_GETTASKDEFREQUEST']._serialized_end=1661
  _globals['_GETTASKDEFRESPONSE']._serialized_start=1663
  _globals['_GETTASKDEFRESPONSE']._serialized_end=1735
  _globals['_GETALLTASKDEFSREQUEST']._serialized_start=1737
  _globals['_GETALLTASKDEFSREQUEST']._serialized_end=1760
  _globals['_GETALLTASKDEFSRESPONSE']._serialized_start=1762
  _globals['_GETALLTASKDEFSRESPONSE']._serialized_end=1839
  _globals['_REGISTERCRONREQUEST']._serialized_start=1841
  _globals['_REGISTERCRONREQUEST']._serialized_end=1862
  _globals['_REGISTERCRONRESPONSE']._serialized_start=1864
  _globals['_REGISTERCRONRESPONSE']._serialized_end=1886
  _globals['_REGISTEREXECUTORREQUEST']._serialized_start=1889
  _globals['_REGISTEREXECUTORREQUEST']._serialized_end=2018
  _globals['_REGISTEREXECUTORRESPONSE']._serialized_start=2020
  _globals['_REGISTEREXECUTORRESPONSE']._serialized_end=2046
  _globals['_UPDATEEXECUTORQUEUESREQUEST']._serialized_start=2048
  _globals['_UPDATEEXECUTORQUEUESREQUEST']._serialized_end=2114
  _globals['_UPDATEEXECUTORQUEUESRESPONSE']._serialized_start=2116
  _globals['_UPDATEEXECUTORQUEUESRESPONSE']._serialized_end=2146
  _globals['_REGISTERAPPREQUEST']._serialized_start=2148
  _globals['_REGISTERAPPREQUEST']._serialized_end=2211
  _globals['_REGISTERAPPRESPONSE']._serialized_start=2213
  _globals['_REGISTERAPPRESPONSE']._serialized_end=2234
  _globals['_ACQUIRESCHEDULERLOCKREQUEST']._serialized_start=2236
  _globals['_ACQUIRESCHEDULERLOCKREQUEST']._serialized_end=2304
  _globals['_ACQUIRESCHEDULERLOCKRESPONSE']._serialized_start=2306
  _globals['_ACQUIRESCHEDULERLOCKRESPONSE']._serialized_end=2370
  _globals['_TESTCONNECTIONREQUEST']._serialized_start=2372
  _globals['_TESTCONNECTIONREQUEST']._serialized_end=2395
  _globals['_TESTCONNECTIONRESPONSE']._serialized_start=2397
  _globals['_TESTCONNECTIONRESPONSE']._serialized_end=2421
# @@protoc_insertion_point(module_scope)
