# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import requests_pb2 as requests__pb2

GRPC_GENERATED_VERSION = '1.71.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in gateway_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class GatewayServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Enqueue = channel.unary_unary(
                '/hyrex.performanceserver.GatewayService/Enqueue',
                request_serializer=requests__pb2.EnqueueRequest.SerializeToString,
                response_deserializer=requests__pb2.EnqueueResponse.FromString,
                _registered_method=True)
        self.Dequeue = channel.unary_unary(
                '/hyrex.performanceserver.GatewayService/Dequeue',
                request_serializer=requests__pb2.DequeueRequest.SerializeToString,
                response_deserializer=requests__pb2.DequeueResponse.FromString,
                _registered_method=True)
        self.GetQueues = channel.unary_unary(
                '/hyrex.performanceserver.GatewayService/GetQueues',
                request_serializer=requests__pb2.GetQueuesRequest.SerializeToString,
                response_deserializer=requests__pb2.GetQueuesResponse.FromString,
                _registered_method=True)
        self.GetTaskRunStatus = channel.unary_unary(
                '/hyrex.performanceserver.GatewayService/GetTaskRunStatus',
                request_serializer=requests__pb2.GetTaskRunStatusRequest.SerializeToString,
                response_deserializer=requests__pb2.GetTaskRunStatusResponse.FromString,
                _registered_method=True)
        self.MarkSuccess = channel.unary_unary(
                '/hyrex.performanceserver.GatewayService/MarkSuccess',
                request_serializer=requests__pb2.MarkSuccessRequest.SerializeToString,
                response_deserializer=requests__pb2.MarkSuccessResponse.FromString,
                _registered_method=True)
        self.MarkFailed = channel.unary_unary(
                '/hyrex.performanceserver.GatewayService/MarkFailed',
                request_serializer=requests__pb2.MarkFailedRequest.SerializeToString,
                response_deserializer=requests__pb2.MarkFailedResponse.FromString,
                _registered_method=True)
        self.GetTaskRun = channel.unary_unary(
                '/hyrex.performanceserver.GatewayService/GetTaskRun',
                request_serializer=requests__pb2.GetTaskRunRequest.SerializeToString,
                response_deserializer=requests__pb2.GetTaskRunResponse.FromString,
                _registered_method=True)
        self.GetDurableTaskRuns = channel.unary_unary(
                '/hyrex.performanceserver.GatewayService/GetDurableTaskRuns',
                request_serializer=requests__pb2.GetDurableTaskRunsRequest.SerializeToString,
                response_deserializer=requests__pb2.GetDurableTaskRunsResponse.FromString,
                _registered_method=True)
        self.RegisterTaskDef = channel.unary_unary(
                '/hyrex.performanceserver.GatewayService/RegisterTaskDef',
                request_serializer=requests__pb2.RegisterTaskDefRequest.SerializeToString,
                response_deserializer=requests__pb2.RegisterTaskDefResponse.FromString,
                _registered_method=True)
        self.GetTaskDef = channel.unary_unary(
                '/hyrex.performanceserver.GatewayService/GetTaskDef',
                request_serializer=requests__pb2.GetTaskDefRequest.SerializeToString,
                response_deserializer=requests__pb2.GetTaskDefResponse.FromString,
                _registered_method=True)
        self.GetAllTaskDefs = channel.unary_unary(
                '/hyrex.performanceserver.GatewayService/GetAllTaskDefs',
                request_serializer=requests__pb2.GetAllTaskDefsRequest.SerializeToString,
                response_deserializer=requests__pb2.GetAllTaskDefsResponse.FromString,
                _registered_method=True)
        self.RegisterExecutor = channel.unary_unary(
                '/hyrex.performanceserver.GatewayService/RegisterExecutor',
                request_serializer=requests__pb2.RegisterExecutorRequest.SerializeToString,
                response_deserializer=requests__pb2.RegisterExecutorResponse.FromString,
                _registered_method=True)
        self.UpdateExecutorQueues = channel.unary_unary(
                '/hyrex.performanceserver.GatewayService/UpdateExecutorQueues',
                request_serializer=requests__pb2.UpdateExecutorQueuesRequest.SerializeToString,
                response_deserializer=requests__pb2.UpdateExecutorQueuesResponse.FromString,
                _registered_method=True)
        self.RegisterApp = channel.unary_unary(
                '/hyrex.performanceserver.GatewayService/RegisterApp',
                request_serializer=requests__pb2.RegisterAppRequest.SerializeToString,
                response_deserializer=requests__pb2.RegisterAppResponse.FromString,
                _registered_method=True)
        self.SetLogLink = channel.unary_unary(
                '/hyrex.performanceserver.GatewayService/SetLogLink',
                request_serializer=requests__pb2.SetLogLinkRequest.SerializeToString,
                response_deserializer=requests__pb2.SetLogLinkResponse.FromString,
                _registered_method=True)
        self.AcquireSchedulerLock = channel.unary_unary(
                '/hyrex.performanceserver.GatewayService/AcquireSchedulerLock',
                request_serializer=requests__pb2.AcquireSchedulerLockRequest.SerializeToString,
                response_deserializer=requests__pb2.AcquireSchedulerLockResponse.FromString,
                _registered_method=True)


class GatewayServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Enqueue(self, request, context):
        """---- Valkey requests ----
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Dequeue(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetQueues(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTaskRunStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MarkSuccess(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MarkFailed(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTaskRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDurableTaskRuns(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterTaskDef(self, request, context):
        """---- Postgres requests ----
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTaskDef(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAllTaskDefs(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterExecutor(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateExecutorQueues(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterApp(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetLogLink(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AcquireSchedulerLock(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_GatewayServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Enqueue': grpc.unary_unary_rpc_method_handler(
                    servicer.Enqueue,
                    request_deserializer=requests__pb2.EnqueueRequest.FromString,
                    response_serializer=requests__pb2.EnqueueResponse.SerializeToString,
            ),
            'Dequeue': grpc.unary_unary_rpc_method_handler(
                    servicer.Dequeue,
                    request_deserializer=requests__pb2.DequeueRequest.FromString,
                    response_serializer=requests__pb2.DequeueResponse.SerializeToString,
            ),
            'GetQueues': grpc.unary_unary_rpc_method_handler(
                    servicer.GetQueues,
                    request_deserializer=requests__pb2.GetQueuesRequest.FromString,
                    response_serializer=requests__pb2.GetQueuesResponse.SerializeToString,
            ),
            'GetTaskRunStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTaskRunStatus,
                    request_deserializer=requests__pb2.GetTaskRunStatusRequest.FromString,
                    response_serializer=requests__pb2.GetTaskRunStatusResponse.SerializeToString,
            ),
            'MarkSuccess': grpc.unary_unary_rpc_method_handler(
                    servicer.MarkSuccess,
                    request_deserializer=requests__pb2.MarkSuccessRequest.FromString,
                    response_serializer=requests__pb2.MarkSuccessResponse.SerializeToString,
            ),
            'MarkFailed': grpc.unary_unary_rpc_method_handler(
                    servicer.MarkFailed,
                    request_deserializer=requests__pb2.MarkFailedRequest.FromString,
                    response_serializer=requests__pb2.MarkFailedResponse.SerializeToString,
            ),
            'GetTaskRun': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTaskRun,
                    request_deserializer=requests__pb2.GetTaskRunRequest.FromString,
                    response_serializer=requests__pb2.GetTaskRunResponse.SerializeToString,
            ),
            'GetDurableTaskRuns': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDurableTaskRuns,
                    request_deserializer=requests__pb2.GetDurableTaskRunsRequest.FromString,
                    response_serializer=requests__pb2.GetDurableTaskRunsResponse.SerializeToString,
            ),
            'RegisterTaskDef': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterTaskDef,
                    request_deserializer=requests__pb2.RegisterTaskDefRequest.FromString,
                    response_serializer=requests__pb2.RegisterTaskDefResponse.SerializeToString,
            ),
            'GetTaskDef': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTaskDef,
                    request_deserializer=requests__pb2.GetTaskDefRequest.FromString,
                    response_serializer=requests__pb2.GetTaskDefResponse.SerializeToString,
            ),
            'GetAllTaskDefs': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAllTaskDefs,
                    request_deserializer=requests__pb2.GetAllTaskDefsRequest.FromString,
                    response_serializer=requests__pb2.GetAllTaskDefsResponse.SerializeToString,
            ),
            'RegisterExecutor': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterExecutor,
                    request_deserializer=requests__pb2.RegisterExecutorRequest.FromString,
                    response_serializer=requests__pb2.RegisterExecutorResponse.SerializeToString,
            ),
            'UpdateExecutorQueues': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateExecutorQueues,
                    request_deserializer=requests__pb2.UpdateExecutorQueuesRequest.FromString,
                    response_serializer=requests__pb2.UpdateExecutorQueuesResponse.SerializeToString,
            ),
            'RegisterApp': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterApp,
                    request_deserializer=requests__pb2.RegisterAppRequest.FromString,
                    response_serializer=requests__pb2.RegisterAppResponse.SerializeToString,
            ),
            'SetLogLink': grpc.unary_unary_rpc_method_handler(
                    servicer.SetLogLink,
                    request_deserializer=requests__pb2.SetLogLinkRequest.FromString,
                    response_serializer=requests__pb2.SetLogLinkResponse.SerializeToString,
            ),
            'AcquireSchedulerLock': grpc.unary_unary_rpc_method_handler(
                    servicer.AcquireSchedulerLock,
                    request_deserializer=requests__pb2.AcquireSchedulerLockRequest.FromString,
                    response_serializer=requests__pb2.AcquireSchedulerLockResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'hyrex.performanceserver.GatewayService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('hyrex.performanceserver.GatewayService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class GatewayService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Enqueue(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyrex.performanceserver.GatewayService/Enqueue',
            requests__pb2.EnqueueRequest.SerializeToString,
            requests__pb2.EnqueueResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Dequeue(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyrex.performanceserver.GatewayService/Dequeue',
            requests__pb2.DequeueRequest.SerializeToString,
            requests__pb2.DequeueResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetQueues(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyrex.performanceserver.GatewayService/GetQueues',
            requests__pb2.GetQueuesRequest.SerializeToString,
            requests__pb2.GetQueuesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTaskRunStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyrex.performanceserver.GatewayService/GetTaskRunStatus',
            requests__pb2.GetTaskRunStatusRequest.SerializeToString,
            requests__pb2.GetTaskRunStatusResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def MarkSuccess(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyrex.performanceserver.GatewayService/MarkSuccess',
            requests__pb2.MarkSuccessRequest.SerializeToString,
            requests__pb2.MarkSuccessResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def MarkFailed(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyrex.performanceserver.GatewayService/MarkFailed',
            requests__pb2.MarkFailedRequest.SerializeToString,
            requests__pb2.MarkFailedResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTaskRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyrex.performanceserver.GatewayService/GetTaskRun',
            requests__pb2.GetTaskRunRequest.SerializeToString,
            requests__pb2.GetTaskRunResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetDurableTaskRuns(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyrex.performanceserver.GatewayService/GetDurableTaskRuns',
            requests__pb2.GetDurableTaskRunsRequest.SerializeToString,
            requests__pb2.GetDurableTaskRunsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RegisterTaskDef(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyrex.performanceserver.GatewayService/RegisterTaskDef',
            requests__pb2.RegisterTaskDefRequest.SerializeToString,
            requests__pb2.RegisterTaskDefResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTaskDef(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyrex.performanceserver.GatewayService/GetTaskDef',
            requests__pb2.GetTaskDefRequest.SerializeToString,
            requests__pb2.GetTaskDefResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetAllTaskDefs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyrex.performanceserver.GatewayService/GetAllTaskDefs',
            requests__pb2.GetAllTaskDefsRequest.SerializeToString,
            requests__pb2.GetAllTaskDefsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RegisterExecutor(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyrex.performanceserver.GatewayService/RegisterExecutor',
            requests__pb2.RegisterExecutorRequest.SerializeToString,
            requests__pb2.RegisterExecutorResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateExecutorQueues(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyrex.performanceserver.GatewayService/UpdateExecutorQueues',
            requests__pb2.UpdateExecutorQueuesRequest.SerializeToString,
            requests__pb2.UpdateExecutorQueuesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RegisterApp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyrex.performanceserver.GatewayService/RegisterApp',
            requests__pb2.RegisterAppRequest.SerializeToString,
            requests__pb2.RegisterAppResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetLogLink(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyrex.performanceserver.GatewayService/SetLogLink',
            requests__pb2.SetLogLinkRequest.SerializeToString,
            requests__pb2.SetLogLinkResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AcquireSchedulerLock(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyrex.performanceserver.GatewayService/AcquireSchedulerLock',
            requests__pb2.AcquireSchedulerLockRequest.SerializeToString,
            requests__pb2.AcquireSchedulerLockResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
